@@ -7,7 +7,7 @@ def change(event, values, window):
     if window['-ACTIONS-CHOICE-'].get() == 'attaching file to file input':
         file_browse_input_not_visible = True
 
-    if window['-ACTIONS-CHOICE-'].get() == 'visiting site':
+    if window['-ACTIONS-CHOICE-'].get() in ['visiting site', 'assert url of site']:
         autocomplete_with_current_domain_visible = True
 
     window['-HELPER-INPUT-FILE-BROWSE-'].update(visible=file_browse_input_not_visible)
