@@ -1,4 +1,5 @@
 import PySimpleGUI as sg
+import os
 
 INFORMATION_ABOUT_UNIQUENESS = 'To have your save buttons enabled, you need to have xpath of your element unique :D'
 
@@ -17,9 +18,10 @@ def get_layout(domain,
                password_field,
                password_value,
                actions,
-               todo_actions_in_array,
+               todo_actions,
                imported_actions
                ):
+    path_of_project = os.getcwd()
     return [
         [
             [
@@ -151,11 +153,16 @@ def get_layout(domain,
                 ],
                 [
                     sg.FileSaveAs("Save configuration", key='-SAVE-CONFIGURATION-', enable_events=True,
+                                  initial_folder=f'{path_of_project}/resources_for_testing/saved_plans',
                                   file_types=[((("PB_CONFIG"), ("*.pb_config")))])
                 ],
                 [
                     sg.FileBrowse("Load configuration", key='-LOAD-CONFIGURATION-', enable_events=True,
+                                  initial_folder=f'{path_of_project}/resources_for_testing/saved_plans',
                                   file_types=[((("PB_CONFIG"), ("*.pb_config")))])
+                ],
+                [
+                    sg.Button("Erase saved htmls", key='-RESET-SAVED-HTMLS-', button_color='black')
                 ]
             ])
         ],
@@ -175,7 +182,7 @@ def get_layout(domain,
                         sg.Combo(actions, default_value=actions[0], key='-ACTIONS-CHOICE-', readonly=True,
                                  enable_events=True),
                         sg.pin(sg.Combo(imported_actions, key='-SAVED-ACTIONS-', readonly=True,
-                                        enable_events=True, visible=False)),
+                                        enable_events=True, visible=False, size=(40, 1))),
                         sg.pin(sg.Button('Reload actions', key='-RELOAD-ACTIONS-', visible=False)),
                         sg.Combo(bdd_attributes, default_value=bdd_attributes[0], key='-BDD-ATTRIBUTE-', readonly=True,
                                  enable_events=True)
@@ -214,10 +221,10 @@ def get_layout(domain,
                                     sg.Column(
                                         [
                                             [
-                                                sg.Button('Copy whole html', button_color='green',
-                                                          key='-COPY-HTML-ELEMENT-'),
                                                 sg.Button('Copy html of element', button_color=('black', 'yellow'),
-                                                          key='-COPY-HTML-')
+                                                          key='-COPY-HTML-ELEMENT-'),
+                                                sg.Button('Copy html of whole site', button_color='green',
+                                                          key='-COPY-HTML-'),
                                             ]
                                         ]
                                     )
@@ -226,9 +233,6 @@ def get_layout(domain,
                                     sg.Button('Check if xpath exists in html', button_color='blue',
                                               key='-XPATH-EXISTS-')
                                 ],
-                                [
-                                    sg.Button('Save xpath', button_color='red', key='-XPATH-SAVE-')
-                                ]
                             ]
                         )
                     ],
@@ -247,7 +251,13 @@ def get_layout(domain,
                         sg.Text("Write here your info for input", key='-HELPER-INPUT-LABEL-')
                     ],
                     [
-                        sg.Input("Additional", key='-HELPER-INPUT-')
+                        sg.Input("Additional", key='-HELPER-INPUT-'),
+                        sg.FileBrowse('Choose folder of your project', target='-HELPER-INPUT-', visible=False,
+                                      key='-HELPER-INPUT-FILE-BROWSE-'),
+                        sg.Button('Insert in input current domain', visible=False, button_color='#007373',
+                                  key='-HELPER-INPUT-CURRENT-DOMAIN-'),
+                        sg.Button('Insert in input current domain with endpoint', visible=False, button_color='#008080',
+                                  key='-HELPER-INPUT-CURRENT-DOMAIN-WITH-ENDPOINT-')
                     ]
                 ], expand_x=True)
             ],
@@ -260,7 +270,7 @@ def get_layout(domain,
             ],
             [
                 sg.Column([[]], k='layout_principal', expand_x=True),
-                sg.Listbox(todo_actions_in_array, size=(20, 18), k='-ACTION-LIST-', expand_x=True, enable_events=True),
+                sg.Listbox(todo_actions, size=(20, 18), k='-ACTION-LIST-', expand_x=True, enable_events=True),
                 sg.Column([[]], k='layout_principal'),
                 sg.Column([
                     [
