@@ -3,7 +3,7 @@ from bs4 import BeautifulSoup
 import mechanize
 from models.website_tag import WebsiteTag
 from models.saved_html import SavedHtml
-
+from services.helper_methods import get_full_url
 
 class SiteInfo:
     def __init__(self):
@@ -14,20 +14,22 @@ class SiteInfo:
     def get_saved_site_anonymous(self, site):
         if site in self.saved_htmls_anonymous:
             self.last_used_html = self.saved_htmls_anonymous[site]
-            print("oddano zapisaną")
+            print("returned html from saved site")
             return self.last_used_html, False
 
         try:
             reqs = requests.get(site)
         except requests.exceptions.ConnectionError:
-            return "Oops!  That was no valid number.  Try again...", True
+            return 'Could not connect to this url. Probably wrong endpoint or server is not up', True
 
         soup = BeautifulSoup(reqs.text, features='lxml')
         self.saved_htmls_anonymous[site] = soup.prettify()
         self.last_used_html = self.saved_htmls_anonymous[site]
-        print("oddano stronę, którą trzeba było wyszukać")
-        return reqs.text, False
+        print("returned newly pinged site")
+        print(self.saved_htmls_anonymous)
+        print(self.saved_htmls_logged_in)
 
+        return reqs.text, False
 
     def get_saved_site_logged_in(self, site, username_field, username_value, password_field, password_value, login_path, domain):
         # global last_used_html
@@ -39,20 +41,21 @@ class SiteInfo:
                     return self.last_used_html, False
 
         browser = mechanize.Browser()
-        if domain.endswith('/') and login_path.startswith("/"):
-            full_login_path = domain + login_path[1:]
-        else:
-            full_login_path = domain + login_path
+
+        full_login_path = get_full_url(domain, login_path)
 
         try:
             ad = browser.open(f"{full_login_path}")
-        except:
-            return 'Could not connect to server', True
+        except mechanize.HTTPError:
+            return 'Could not connect to this url. Probably wrong endpoint or server is not up', True
 
-        browser.select_form(nr=0)
-        browser[username_field] = username_value
-        browser[password_field] = password_value
-        browser.submit()
+        browser.select_form(nr=0) #probably not a wise choice, but most of sites have only one form in login :D
+        try:
+            browser[username_field] = username_value
+            browser[password_field] = password_value
+            browser.submit()
+        except mechanize._form_controls.ControlNotFoundError:
+            return 'Could not use given credentials. Probably username input name or password input name is wrong', True
 
         ad = browser.open(site)
         request_from_site = ad.read()
@@ -65,7 +68,10 @@ class SiteInfo:
             self.saved_htmls_logged_in[site] = [SavedHtml(site, username_value, password_value, html_from_site)]
 
         self.last_used_html = html_from_site
-        print("oddano stronę, którą trzeba było wyszukać")
+        print("returned newly pinged site")
+        print(self.saved_htmls_anonymous)
+        print(self.saved_htmls_logged_in)
+
         return request_from_site, False
 
     def get_last_used_html(self):
@@ -103,3 +109,7 @@ class SiteInfo:
         tags = self.get_tag(html, tag=tag, tag_attributes=tag_attributes)
 
         return tags, thrown_exception
+
+    def clear_saved_htmls(self):
+        self.saved_htmls_anonymous.clear()
+        self.saved_htmls_logged_in.clear()
